==> fltk-1.3.7-1-aarch64.pkg.tar.xz: usr/share/fltk/FLTK-Targets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "fluid" for configuration "None"
set_property(TARGET fluid APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fluid PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/bin/fluid"
  )

list(APPEND _IMPORT_CHECK_TARGETS fluid )
list(APPEND _IMPORT_CHECK_FILES_FOR_fluid "${_IMPORT_PREFIX}/bin/fluid" )

# Import target "fltk" for configuration "None"
set_property(TARGET fltk APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "C;CXX"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk "/usr/lib/libfltk.a" )

# Import target "fltk_forms" for configuration "None"
set_property(TARGET fltk_forms APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_forms PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "CXX"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_forms.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_forms )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_forms "/usr/lib/libfltk_forms.a" )

# Import target "fltk_images" for configuration "None"
set_property(TARGET fltk_images APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_images PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "CXX"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_images.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_images )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_images "/usr/lib/libfltk_images.a" )

# Import target "fltk_gl" for configuration "None"
set_property(TARGET fltk_gl APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_gl PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "CXX"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_gl.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_gl )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_gl "/usr/lib/libfltk_gl.a" )

# Import target "fltk_SHARED" for configuration "None"
set_property(TARGET fltk_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_SHARED PROPERTIES
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk.so.1.3.7"
  IMPORTED_SONAME_NONE "libfltk.so.1.3"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_SHARED )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_SHARED "/usr/lib/libfltk.so.1.3.7" )

# Import target "fltk_forms_SHARED" for configuration "None"
set_property(TARGET fltk_forms_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_forms_SHARED PROPERTIES
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_forms.so.1.3.7"
  IMPORTED_SONAME_NONE "libfltk_forms.so.1.3"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_forms_SHARED )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_forms_SHARED "/usr/lib/libfltk_forms.so.1.3.7" )

# Import target "fltk_images_SHARED" for configuration "None"
set_property(TARGET fltk_images_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_images_SHARED PROPERTIES
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_images.so.1.3.7"
  IMPORTED_SONAME_NONE "libfltk_images.so.1.3"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_images_SHARED )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_images_SHARED "/usr/lib/libfltk_images.so.1.3.7" )

# Import target "fltk_gl_SHARED" for configuration "None"
set_property(TARGET fltk_gl_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_gl_SHARED PROPERTIES
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_gl.so.1.3.7"
  IMPORTED_SONAME_NONE "libfltk_gl.so.1.3"
  )

list(APPEND _IMPORT_CHECK_TARGETS fltk_gl_SHARED )
list(APPEND _IMPORT_CHECK_FILES_FOR_fltk_gl_SHARED "/usr/lib/libfltk_gl.so.1.3.7" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> fltk-1.3.8-2-aarch64.pkg.tar.xz: usr/share/fltk/FLTK-Targets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "fluid" for configuration "None"
set_property(TARGET fluid APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fluid PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/bin/fluid"
  )

list(APPEND _cmake_import_check_targets fluid )
list(APPEND _cmake_import_check_files_for_fluid "${_IMPORT_PREFIX}/bin/fluid" )

# Import target "fltk" for configuration "None"
set_property(TARGET fltk APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "C;CXX"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk.a"
  )

list(APPEND _cmake_import_check_targets fltk )
list(APPEND _cmake_import_check_files_for_fltk "/usr/lib/libfltk.a" )

# Import target "fltk_forms" for configuration "None"
set_property(TARGET fltk_forms APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_forms PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "CXX"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_forms.a"
  )

list(APPEND _cmake_import_check_targets fltk_forms )
list(APPEND _cmake_import_check_files_for_fltk_forms "/usr/lib/libfltk_forms.a" )

# Import target "fltk_images" for configuration "None"
set_property(TARGET fltk_images APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_images PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "CXX"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_images.a"
  )

list(APPEND _cmake_import_check_targets fltk_images )
list(APPEND _cmake_import_check_files_for_fltk_images "/usr/lib/libfltk_images.a" )

# Import target "fltk_gl" for configuration "None"
set_property(TARGET fltk_gl APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_gl PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NONE "CXX"
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_gl.a"
  )

list(APPEND _cmake_import_check_targets fltk_gl )
list(APPEND _cmake_import_check_files_for_fltk_gl "/usr/lib/libfltk_gl.a" )

# Import target "fltk_SHARED" for configuration "None"
set_property(TARGET fltk_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_SHARED PROPERTIES
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk.so.1.3.8"
  IMPORTED_SONAME_NONE "libfltk.so.1.3"
  )

list(APPEND _cmake_import_check_targets fltk_SHARED )
list(APPEND _cmake_import_check_files_for_fltk_SHARED "/usr/lib/libfltk.so.1.3.8" )

# Import target "fltk_forms_SHARED" for configuration "None"
set_property(TARGET fltk_forms_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_forms_SHARED PROPERTIES
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_forms.so.1.3.8"
  IMPORTED_SONAME_NONE "libfltk_forms.so.1.3"
  )

list(APPEND _cmake_import_check_targets fltk_forms_SHARED )
list(APPEND _cmake_import_check_files_for_fltk_forms_SHARED "/usr/lib/libfltk_forms.so.1.3.8" )

# Import target "fltk_images_SHARED" for configuration "None"
set_property(TARGET fltk_images_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_images_SHARED PROPERTIES
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_images.so.1.3.8"
  IMPORTED_SONAME_NONE "libfltk_images.so.1.3"
  )

list(APPEND _cmake_import_check_targets fltk_images_SHARED )
list(APPEND _cmake_import_check_files_for_fltk_images_SHARED "/usr/lib/libfltk_images.so.1.3.8" )

# Import target "fltk_gl_SHARED" for configuration "None"
set_property(TARGET fltk_gl_SHARED APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(fltk_gl_SHARED PROPERTIES
  IMPORTED_LOCATION_NONE "/usr/lib/libfltk_gl.so.1.3.8"
  IMPORTED_SONAME_NONE "libfltk_gl.so.1.3"
  )

list(APPEND _cmake_import_check_targets fltk_gl_SHARED )
list(APPEND _cmake_import_check_files_for_fltk_gl_SHARED "/usr/lib/libfltk_gl.so.1.3.8" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
